@@ -12,7 +12,7 @@ function(x, data = NULL, na.action = na.omit, ...)
     mf <- match.call(expand.dots = FALSE)
     mf$formula <- mf$x
     mf$... <- NULL
-    mf[[1]] <- as.name("model.frame")
+    mf[[1L]] <- quote(stats::model.frame)
     mf <- eval(mf, parent.frame())
     na.act <- attr(mf, "na.action")
     x <- model.matrix(mt, mf)
@@ -64,10 +64,10 @@ setMethod("kkmeans",signature(x="matrix"),function(x, centers, kernel
      }
   
   if (!is.function(kernel))
-  if (!is.list(kpar)&&is.character(kpar)&&(class(kernel)=="rbfkernel" || class(kernel) =="laplacedot" || kernel == "laplacedot"|| kernel=="rbfdot")){
+  if (!is.list(kpar)&&is.character(kpar)&&(is(kernel, "rbfkernel") || is(kernel, "laplacedot") || kernel == "laplacedot"|| kernel=="rbfdot")){
     kp <- match.arg(kpar,"automatic")
     if(kp=="automatic")
-      kpar <- list(sigma=sigest(x,scaled=FALSE)[2])
+      kpar <- list(sigma=mean(sigest(x,scaled=FALSE)[c(1,3)]))
    cat("Using automatic sigma estimation (sigest) for RBF or laplace kernel","\n")
    
   }
